@@ -1,7 +1,7 @@
 package Git::Bunch;
 
-our $DATE = '2019-11-29'; # DATE
-our $VERSION = '0.625'; # VERSION
+our $DATE = '2020-01-31'; # DATE
+our $VERSION = '0.626'; # VERSION
 
 use 5.010001;
 use strict;
@@ -163,7 +163,7 @@ interested in recent repos (which is most of the time unless you are doing a
 full check/sync).
 
 _
-        schema => ['date*', 'x.perl.coerce_rules' => ['!From_float::epoch', 'From_float::epoch_always', 'From_str::alami_en']],
+        schema => ['date*', 'x.perl.coerce_rules' => ['!From_float::epoch', 'From_float::epoch_always', 'From_str::natural']],
         tags => ['filter'],
     },
 );
@@ -1164,7 +1164,7 @@ Git::Bunch - Manage gitbunch directory (directory which contain git repos)
 
 =head1 VERSION
 
-This document describes version 0.625 of Git::Bunch (from Perl distribution Git-Bunch), released on 2019-11-29.
+This document describes version 0.626 of Git::Bunch (from Perl distribution Git-Bunch), released on 2020-01-31.
 
 =head1 SYNOPSIS
 
@@ -1273,6 +1273,7 @@ Only process a single repo.
 
 Directory to check.
 
+
 =back
 
 Special arguments:
@@ -1281,7 +1282,7 @@ Special arguments:
 
 =item * B<-dry_run> => I<bool>
 
-Pass -dry_run=>1 to enable simulation mode.
+Pass -dry_run=E<gt>1 to enable simulation mode.
 
 =back
 
@@ -1368,6 +1369,7 @@ Only process a single repo.
 
 Directory to check.
 
+
 =back
 
 Special arguments:
@@ -1376,7 +1378,7 @@ Special arguments:
 
 =item * B<-dry_run> => I<bool>
 
-Pass -dry_run=>1 to enable simulation mode.
+Pass -dry_run=E<gt>1 to enable simulation mode.
 
 =back
 
@@ -1463,6 +1465,7 @@ Order entries.
 
 Directory to check.
 
+
 =back
 
 Returns an enveloped result (an array).
@@ -1619,6 +1622,7 @@ Directory to check.
 
 Destination bunch.
 
+
 =back
 
 Special arguments:
@@ -1627,7 +1631,7 @@ Special arguments:
 
 =item * B<-dry_run> => I<bool>
 
-Pass -dry_run=>1 to enable simulation mode.
+Pass -dry_run=E<gt>1 to enable simulation mode.
 
 =back
 
@@ -1682,7 +1686,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019, 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2019, 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
